<?php

/**
 * Register Portfolio custom post type
 *
 * @todo Rewrite portfolio permalink slug from theme options
 */
function qodx_fw_register_portfolio() {
 
	$slug = 'portfolio';

    $labels = array( 
        'name' 				 => esc_html_x( 'Portfolio', 'post type general name', 'qodux_fw' ),
        'singular_name'		 => esc_html_x( 'Portfolio', 'post type singular name', 'qodux_fw' ),
        'add_new'			 => esc_html__( 'Add New', 'qodux_fw' ),
        'add_new_item'		 => esc_html__( 'Add New Portfolio', 'qodux_fw' ),
        'edit_item'			 => esc_html__( 'Edit Portfolio', 'qodux_fw' ),
        'new_item'           => esc_html__( 'New Portfolio', 'qodux_fw' ),
        'view_item'          => esc_html__( 'View Portfolio', 'qodux_fw' ),
        'search_items'       => esc_html__( 'Search Portfolios', 'qodux_fw' ),
        'not_found'          => esc_html__( 'No portfolios found', 'qodux_fw' ),
        'not_found_in_trash' => esc_html__( 'No portfolios found in Trash', 'qodux_fw' ),
        'parent_item_colon'  => esc_html__( 'Parent Portfolio:', 'qodux_fw' ),
        'menu_name' 		 => esc_html__( 'Portfolio', 'qodux_fw' ),
    );

    $args = array( 
        'labels' 			  => $labels,
        'hierarchical'  	  => false,
        'description'   	  => esc_html__( 'Portfolio entries for the Qodux Themes.', 'qodux_fw' ),
        'supports' 			  => array( 'title', 'editor', 'thumbnail', 'excerpt', 'page-attributes', 'post-formats', 'comments', 'custom-fields' ),
        'public' 			  => true,
        'show_ui' 			  => true,
        'show_in_menu'  	  => true,
        'menu_position'		  => 5,
        'menu_icon'     	  => 'dashicons-portfolio',
		        
        'show_in_nav_menus'   => true,
        'publicly_queryable'  => true,
        'exclude_from_search' => false,
        'has_archive'         => true,
        'query_var' 		  => true,
        'can_export' 		  => true,
        'rewrite' 			  => array( 'slug' => $slug ),
        'capability_type'	  => 'post'
    );

    register_post_type( 'portfolio', $args );
}

/**
 * Register taxonomies for portfolio custom post type
 */
function qodx_fw_register_portfolio_taxonomies(){
	
	$labels = array(
	    'name'              => esc_html_x( 'Portfolio Categories', 'taxonomy general name', 'qodux_fw' ),
	    'singular_name'     => esc_html_x( 'Portfolio Category', 'taxonomy singular name', 'qodux_fw' ),
	    'search_items'      => esc_html__( 'Search Portfolio Categories', 'qodux_fw' ),
	    'popular_items'     => esc_html__( 'Popular Portfolio Categories', 'qodux_fw' ),
	    'all_items'         => esc_html__( 'All Portfolio Categories', 'qodux_fw' ),
	    'parent_item'       => esc_html__( 'Parent Portfolio Category', 'qodux_fw' ),
	    'parent_item_colon' => esc_html__( 'Parent Portfolio Category:', 'qodux_fw' ),
	    'edit_item'         => esc_html__( 'Edit Portfolio Category', 'qodux_fw' ), 
	    'update_item'       => esc_html__( 'Update Portfolio Category', 'qodux_fw' ),
	    'add_new_item'      => esc_html__( 'Add New Portfolio Category', 'qodux_fw' ),
	    'new_item_name'     => esc_html__( 'New Portfolio Category Name', 'qodux_fw' ),
	    'menu_name'         => esc_html__( 'Portfolio Categories', 'qodux_fw' ),
	  );
	   	
	register_taxonomy('portfolio_category', array('portfolio'), array(
		'hierarchical'      => true,
		'labels'            => $labels,
		'show_ui'           => true,
		'show_admin_column' => true,
		'query_var'         => true,
		'rewrite'           => true,
	));
	
}

/**
 * Register Team custom post type
 *
 * @todo Rewrite team permalink slug from theme options
 */
function qodx_fw_register_team() {
 
	$slug = 'team';

    $labels = array( 
        'name' 				 => esc_html_x( 'Team Members', 'post type general name', 'qodux_fw' ),
        'singular_name' 	 => esc_html_x( 'Team Member', 'post type singular name', 'qodux_fw' ),
        'add_new' 			 => esc_html__( 'Add New', 'qodux_fw' ),
        'add_new_item' 	 	 => esc_html__( 'Add New Team Member', 'qodux_fw' ),
        'edit_item' 		 => esc_html__( 'Edit Team Member', 'qodux_fw' ),
        'new_item' 			 => esc_html__( 'New Team Member', 'qodux_fw' ),
        'view_item' 		 => esc_html__( 'View Team Member', 'qodux_fw' ),
        'search_items'  	 => esc_html__( 'Search Team Members', 'qodux_fw' ),
        'not_found' 		 => esc_html__( 'No Team Members found', 'qodux_fw' ),
        'not_found_in_trash' => esc_html__( 'No Team Members found in Trash', 'qodux_fw' ),
        'parent_item_colon'  => esc_html__( 'Parent Team Member:', 'qodux_fw' ),
        'menu_name' 		 => esc_html__( 'Team Members', 'qodux_fw' ),
    );

    $args = array( 
        'labels' 			  => $labels,
        'hierarchical'		  => false,
        'description' 		  => esc_html__( 'Team Member entries for the Qodux Themes.', 'qodux_fw' ),
        'supports' 			  => array( 'title', 'editor', 'thumbnail', 'excerpt' ),
        'public' 			  => true,
        'show_ui' 			  => true,
        'show_in_menu' 		  => true,
        'menu_position'		  => 5,
        'menu_icon' 		  => 'dashicons-groups',
		
        'show_in_nav_menus'   => true,
        'publicly_queryable'  => true,
        'exclude_from_search' => false,
        'has_archive' 		  => true,
        'query_var' 		  => true,
        'can_export' 		  => true,
        'rewrite' 			  => array( 'slug' => $slug ),
        'capability_type' 	  => 'post'
    );

    register_post_type( 'team', $args );
}

/**
 * Register taxonomies for team custom post type
 */
function qodx_fw_register_team_taxonomies(){
	
	$labels = array(
		'name'			 	=> esc_html_x( 'Team Categories', 'taxonomy general name', 'qodux_fw' ),
		'singular_name' 	=> esc_html_x( 'Team Category', 'taxonomy singular name', 'qodux_fw' ),
		'search_items' 		=> esc_html__( 'Search Team Categories', 'qodux_fw' ),
		'all_items' 		=> esc_html__( 'All Team Categories', 'qodux_fw' ),
		'parent_item' 		=> esc_html__( 'Parent Team Category', 'qodux_fw' ),
		'parent_item_colon' => esc_html__( 'Parent Team Category:', 'qodux_fw' ),
		'edit_item'		    => esc_html__( 'Edit Team Category', 'qodux_fw' ), 
		'update_item' 		=> esc_html__( 'Update Team Category', 'qodux_fw' ),
		'add_new_item' 		=> esc_html__( 'Add New Team Category', 'qodux_fw' ),
		'new_item_name'		=> esc_html__( 'New Team Category Name', 'qodux_fw' ),
		'menu_name' 		=> esc_html__( 'Team Categories', 'qodux_fw' ),
	); 
		
	register_taxonomy('team_category', array('team'), array(
		'hierarchical'		=> true,
		'labels' 			=> $labels,
		'show_ui' 			=> true,
		'show_admin_column' => true,
		'query_var' 		=> true,
		'rewrite'			=> true,
	));
  
}