<?php
/**
 * Instagram Widget Class
 */
 
// File Security Check
if (!defined('ABSPATH')) die('-1');
 
// Start widget class
class Focus_WP_Widget_Instagram extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'instagram-widget-block', 'description' => esc_html__( 'Grid photos from Instagram', 'qodux_fw' ));
		parent::__construct('instagram', QODUX_FRAME_NAME.' - '.esc_html__( 'Instagram', 'qodux_fw' ), $widget_ops);
	}
	
	function widget( $args, $instance ) {
		// Set vars for widget usage
		extract( $args );
		$title    = isset( $instance['title'] ) ? apply_filters( 'widget_title', $instance['title'] ) : '';
		
		$username = empty( $instance['username'] ) ? '' : $instance['username'];
		$target   = empty( $instance['target'] ) ? '_blank' : $instance['target'];
		$number   = (int)$instance['count'];
								
		if(empty($number)){
			$number = 6;
		} else if ($number < 1){
			$number = 1;
		}
		
		echo balanceTags( $before_widget );
		
		if ( $title) {
			echo balanceTags( $before_title . $title . $after_title );
		} ?>
        
		<div class="instagram-feed-block"> 
            <div class="instagram-feed-block-container">    
                <?php
                // Display notice for username not added
                if ( ! $username ) {
    
                    echo '<p>'. esc_html__( 'Please enter the username for instagram widget.', 'qodux_fw' ) .'</p>';
    
                } else {
    
                    // Get instagram images
                    $media_array = $this->scrape_instagram( $username, $number );
    
                    // Display error message
                    if ( is_wp_error( $media_array ) ) {
    
                        echo strip_tags( $media_array->get_error_message() );
    
                    }
    
                    // Display instagram
                    elseif ( is_array( $media_array ) ) { ?>
    
						<?php
                        $count = 0;
                        foreach ( $media_array as $item ) {
                            $image = ! empty( $item['thumbnail_src'] ) ? $item['thumbnail_src'] : $item['display_src'];
                            if ( $image ) {
                                $count++;
                                echo '<a class="qodx-instagram-item count-'. esc_attr( $count ) .'" href="'. esc_url( $item['link'] ) .'" title="'. esc_attr( $item['description'] ) .'" target="'. esc_attr( $target ) .'">
										<img src="'. esc_url( $image ) .'"  alt="'. esc_attr( $item['description'] ) .'" />
									  </a>';
                            }
                        } ?>
                            
                <?php }
    
                }
                ?> 	
            </div> <!-- .instagram-feed-block-container -->
		</div> <!-- .instagram-feed-block -->
        
		<?php
		echo balanceTags( $after_widget );
	}
	
	function update( $new_instance, $old_instance ) {
		// Get instanc
		$instance             = $old_instance;
		$instance['title']    = strip_tags( $new_instance['title'] );
		$instance['username'] = trim( strip_tags( $new_instance['username'] ) );
		$instance['target']   = strip_tags( $new_instance['target'] );
		$instance['count']    = (int) $new_instance['count'];
		
		return $instance;
	}

	function form( $instance ) {
		$title    = isset($instance['title'])    ? esc_attr($instance['title'])    : '';
		$username = isset($instance['username']) ? esc_attr($instance['username']) : '';
		$target   = isset($instance['target'])   ? esc_attr($instance['target'])   : '_blank';
		$number   = isset($instance['count'])    ? absint($instance['count'])      : 6;
?>
		<p><label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>"><?php esc_html_e( 'Title:', 'qodux_fw' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /></p>
        
		<p><label for="<?php echo esc_attr( $this->get_field_id('username') ); ?>"><?php esc_html_e( 'Username:', 'qodux_fw' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('username') ); ?>" name="<?php echo esc_attr( $this->get_field_name('username') ); ?>" type="text" value="<?php echo esc_attr( $username ); ?>" /></p>
		
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id('target') ); ?>"><?php esc_html_e( 'Open links target:', 'qodux_fw' ); ?></label>
			<select name="<?php echo esc_attr( $this->get_field_name('target') ); ?>" id="<?php echo esc_attr( $this->get_field_id('target') ); ?>" class="widefat">
				<option value="_blank"<?php selected( $target, '_blank' ); ?>><?php esc_html_e( 'New window', 'qodux_fw' ); ?></option>
				<option value="_self"<?php selected( $target, '_self' );?>><?php esc_html_e( 'Current window', 'qodux_fw' ); ?></option>
			</select>
		</p>
				
		<p><label for="<?php echo esc_attr( $this->get_field_id('count') ); ?>"><?php esc_html_e( 'Number of photo to show:', 'qodux_fw' ); ?></label>
		<input id="<?php echo esc_attr( $this->get_field_id('count') ); ?>" name="<?php echo esc_attr( $this->get_field_name('count') ); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" size="3" /></p>        
        
		<p><strong><?php esc_html_e( 'Cache Notice', 'qodux_fw' ); ?></strong>:&nbsp;<?php esc_html_e( 'The instagram feed is refreshed every 2 hours. However, in order to refresh it instantly, just click the save button below to clear the transient.', 'qodux_fw' ); ?></p>
<?php
	}
	
	/**
	 * Get instagram items
	 *
	 * @link  https://gist.github.com/cosmocatalano/4544576
	 */
	function scrape_instagram( $username, $slice = 4 ) {
		
		//returns a big old hunk of JSON from a non-private IG account page.		
		$username           = strtolower( $username );
		$sanitized_username = sanitize_title_with_dashes( $username );
		$transient_name     = 'qodx-instagram-widget-transient-'. $sanitized_username;
		$instagram          = get_transient( $transient_name );

		if ( ! empty( $_GET['theme_clear_transients'] ) ) {
			$instagram = delete_transient( $transient_name );
		}

		if ( ! $instagram ) {

			$remote = wp_remote_get( 'http://instagram.com/'. trim( $username ) );

			if ( is_wp_error( $remote ) ) {
				return new WP_Error( 'site_down', esc_html__( 'Unable to communicate with Instagram.', 'qodux_fw' ) );
			}

			if ( 200 != wp_remote_retrieve_response_code( $remote ) ) {
				return new WP_Error( 'invalid_response', esc_html__( 'Instagram did not return a 200.', 'qodux_fw' ) );
			}

			$shards      = explode( 'window._sharedData = ', $remote['body'] );
			$insta_json  = explode( ';</script>', $shards[1] );
			$insta_array = json_decode( $insta_json[0], TRUE );

			if ( ! $insta_array ) {
				return new WP_Error( 'bad_json', esc_html__( 'Instagram has returned invalid data.', 'qodux_fw' ) );
			}

			// Old style
			if ( isset( $insta_array['entry_data']['UserProfile'][0]['userMedia'] ) ) {
				$images = $insta_array['entry_data']['UserProfile'][0]['userMedia'];
				$type = 'old';

			}

			// New style
			elseif ( isset( $insta_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'] ) ) {
				$images = $insta_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'];
				$type = 'new';
			}

			// Invalid json data
			else {
				return new WP_Error( 'bad_json_2', esc_html__( 'Instagram has returned invalid data.', 'qodux_fw' ) );
			}

			// Invalid data
			if ( ! is_array( $images ) ) {
				return new WP_Error( 'bad_array', esc_html__( 'Instagram has returned invalid data.', 'qodux_fw' ) );
			}

			$instagram = array();

			switch ( $type ) {

				case 'old':

					foreach ( $images as $image ) {
						if ( $image['user']['username'] == $username ) {
							$image['link']						    = preg_replace( "/^http:/i", "", $image['link'] );
							$image['images']['thumbnail']		    = preg_replace( "/^http:/i", "", $image['images']['thumbnail'] );
							$image['images']['standard_resolution'] = preg_replace( "/^http:/i", "", $image['images']['standard_resolution'] );
							$image['images']['low_resolution']	    = preg_replace( "/^http:/i", "", $image['images']['low_resolution'] );
							$instagram[] = array(
								'description' => $image['caption']['text'],
								'link'        => $image['link'],
								'time'        => $image['created_time'],
								'comments'    => $image['comments']['count'],
								'likes'       => $image['likes']['count'],
								'thumbnail'   => $image['images']['thumbnail'],
								'large'       => $image['images']['standard_resolution'],
								'small'       => $image['images']['low_resolution'],
								'type'        => $image['type'],
							);
						}
					}

				break;

				default:

					foreach ( $images as $image ) {

						$image['display_src'] = preg_replace( "/^http:/i", "", $image['display_src'] );

						if ( $image['is_video']  == true ) {
							$type = 'video';
						} else {
							$type = 'image';
						}

						$instagram[] = array(
							'description'   => esc_html__( 'Instagram Image', 'qodux_fw' ),
							'link'		    => '//instagram.com/p/' . $image['code'],
							'time'		    => $image['date'],
							'comments'	    => $image['comments']['count'],
							'likes'		    => $image['likes']['count'],
							'thumbnail_src' => isset( $image['thumbnail_src'] ) ? $image['thumbnail_src'] : '',
							'display_src'   => $image['display_src'],
							'type'		    => $type,
						);

					}

				break;

			}

			// Set transient if not empty
			if ( ! empty( $instagram ) ) {
				$instagram = serialize( $instagram );
				set_transient(
					$transient_name,
					$instagram,
					apply_filters( 'qodx_instagram_widget_cache_time', 2 * HOUR_IN_SECONDS )
				);
			}

		}

		// Return array
		if ( ! empty( $instagram )  ) {
			$instagram = unserialize( $instagram );
			return array_slice( $instagram, 0, $slice );
		}

		// No images returned
		else {

			return new WP_Error( 'no_images', esc_html__( 'Instagram did not return any images.', 'qodux_fw' ) );

		}

	}
}