<?php
/**
 * Visual Composer Column Configuration
 *
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Global var for class
global $qodx_vc_single_image_config;

// Start Class
if ( ! class_exists( 'QODX_VC_Single_Image_Config' ) ) {
	
	class QODX_VC_Single_Image_Config {

		/**
		 * Main constructor
		 *
		 */
		public function __construct() {

			// Add new parameters to the column
			add_action( 'init', array( $this, 'add_remove_params' ) );

		}

		/**
		 * Adds new params for the VC Columns
		 *
		 */
		public function add_remove_params() {

			// Array of params to add
			$add_params = array();
					
			$add_params['onclick'] = array(
				'type'        => 'dropdown',
				'heading'     => esc_html__( 'On click action', 'focus_wp' ),
				'param_name'  => 'onclick',
				'value' => array(
					esc_html__( 'None', 'focus_wp' )                => '',
					esc_html__( 'Link to large image', 'focus_wp' ) => 'img_link_large',
					esc_html__( 'Open Fancybox', 'focus_wp' )       => 'link_image_fancy',
					esc_html__( 'Open prettyPhoto', 'focus_wp' )    => 'link_image',
					esc_html__( 'Open custom link', 'focus_wp' )    => 'custom_link',
					esc_html__( 'Zoom', 'focus_wp' )                => 'zoom',
				),
				'description' => esc_html__( 'Select action for click action.', 'focus_wp' ),
				'std'         => ''
			);
						
			$add_params['image_container'] = array(
				'type'         => 'dropdown',
				'heading'      => esc_html__( 'Container for image?', 'focus_wp' ),
				'param_name'   => 'image_container',
				'value'        => array( 
					esc_html__( 'No', 'focus_wp' )    => 'false',
					esc_html__( 'Yes', 'focus_wp' )   => 'true',
				),
				'description'  => esc_html__( 'If selected, the image will be wrapped by a separate column container.', 'focus_wp' ),
				'group'        => esc_html__( 'Qodux', 'focus_wp' )
			);
			
			$add_params['image_style'] = array(
				'type'         => 'dropdown',
				'heading'      => esc_html__( 'Background image style?', 'focus_wp' ),
				'param_name'   => 'image_style',
				'value'        => array( 
					esc_html__( 'No', 'focus_wp' )    => 'false',
					esc_html__( 'Yes', 'focus_wp' )   => 'true',
				),
				'description'  => esc_html__( 'Here you can selected image style - background / simple image.', 'focus_wp' ),
				'group'        => esc_html__( 'Qodux', 'focus_wp' )
			);
			
			$add_params['image_2'] = array(
				'type'         => 'attach_image',
				'heading'      => esc_html__( 'Image #2', 'focus_wp' ),
				'param_name'   => 'image_2',
				'value'        => '',
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'  => array(
					'element' => 'image_style',
					'value'   => 'false',
				),
				'description'  => esc_html__( 'Select a second image from media library. This image will be displayed after the original one. ', 'focus_wp' ),
				'group'        => esc_html__( 'Qodux', 'focus_wp' )
			);
			
			$add_params['image_3'] = array(
				'type'         => 'attach_image',
				'heading'      => esc_html__( 'Image #3', 'focus_wp' ),
				'param_name'   => 'image_3',
				'value'        => '',
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'  => array(
					'element' => 'image_style',
					'value'   => 'false',
				),
				'description'  => esc_html__( 'Select a third image from media library. This image will be displayed after the second one. ', 'focus_wp' ),
				'group'        => esc_html__( 'Qodux', 'focus_wp' )
			);
			
			$add_params['image_position'] = array(
				'type'         => 'dropdown',
				'heading'      => esc_html__( 'Image position', 'focus_wp' ),
				'param_name'   => 'image_position',
				'value' => array( 
					esc_html__( 'Relative', 'focus_wp' )   => 'relative',
					esc_html__( 'Absolute', 'focus_wp' )   => 'absolute',
				),
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'  => array(
					'element' => 'image_style',
					'value'   => 'false',
				),
				'description'  => esc_html__( 'Specify image position in case of a simple image and not a background one.', 'focus_wp' ),
				'group'        => esc_html__( 'Qodux', 'focus_wp' )
			);
			
			$add_params['mobile_image'] = array(
				'type'         => 'attach_image',
				'heading'      => esc_html__( 'Mobile Image', 'focus_wp' ),
				'param_name'   => 'mobile_image',
				'value'        => '',
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'  => array(
					'element' => 'image_style',
					'value'   => 'true',
				),
				'description'  => esc_html__( 'Select image from media library. This image will be displayed on mobile devices instead the original one.', 'focus_wp' ),
				'group'        => esc_html__( 'Qodux', 'focus_wp' )
			);
			
			$add_params['add_circle_btn'] = array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Add circle button?', 'focus_wp' ),
				'param_name'  => 'add_circle_btn',
				'value'       => array( esc_html__( 'Yes', 'focus_wp' ) => 'yes' ),
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'  => array(
					'element' => 'image_style',
					'value'   => 'true',
				),
				'description' => esc_html__( 'Add circle button that could have a video Fancybox link.', 'focus_wp' ),
				'group'       => esc_html__( 'Qodux', 'focus_wp' )
			);
			
			$add_params['btn_link'] = array(
				'type'        => 'href',
				'heading'     => esc_html__( 'Button link', 'focus_wp' ),
				'param_name'  => 'btn_link',
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'  => array(
					'element' => 'image_style',
					'value'   => 'true',
				),
				'description' => esc_html__( 'Enter URL if you want this image to have a link.', 'focus_wp' ),
				'group'       => esc_html__( 'Qodux', 'focus_wp' )
			);
			
			$add_params['parallax'] = array(
				'type'         => 'dropdown',
				'heading'      => esc_html__( 'Image with parallax effect', 'focus_wp' ),
				'param_name'   => 'parallax',
				'value' => array( 
					esc_html__( 'No', 'focus_wp' )    => 'false',
					esc_html__( 'Yes', 'focus_wp' )   => 'true',
				),
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'  => array(
					'element' => 'image_style',
					'value'   => 'true',
				),
				'description'  => esc_html__( 'Specifically for background image style, the image will have a parallax effect when scrolling.', 'focus_wp' ),
				'group'        => esc_html__( 'Qodux', 'focus_wp' )
			);
			
			$add_params['specific_image'] = array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Specific image?', 'focus_wp' ),
				'param_name'  => 'specific_image',
				'value'       => array( esc_html__( 'Yes', 'focus_wp' ) => 'yes' ),
				'param_holder_class' => 'border_box qodx_dependency',
				'dependency'  => array(
					'element' => 'image_style',
					'value'   => 'true',
				),
				'description' => esc_html__( 'Add specific class to image container needed for responsive custom styles.', 'focus_wp' ),
				'group'       => esc_html__( 'Qodux', 'focus_wp' )
			);
			
			$add_params['remove_containers'] = array(
				'type'        => 'checkbox',
				'heading'     => esc_html__( 'Remove all containers?', 'focus_wp' ),
				'param_name'  => 'remove_containers',
				'value'       => array( esc_html__( 'Yes', 'focus_wp' ) => 'yes' ),
				'description' => esc_html__( 'This option removes all container blocks that wrap the image. By selecting it, all the options previouselly selected could have any effect.', 'focus_wp' ),
				'group'       => esc_html__( 'Qodux', 'focus_wp' )
			);
			
			// Loop through array and add new params
			foreach( $add_params as $key => $val ) {
				vc_add_param( 'vc_single_image', $val );
			}

		}
		
	}

}
$qodx_vc_single_image_config = new QODX_VC_Single_Image_Config();