/**
 * Qodux Extend Visual Composer Google Map
 *
 * Google Map Options with markerclusterer enabled
 */
 
function qodx_vcsc_extend_google_map(map_options) {	
    // console.log(map_options);	   
    var options = {
            mapTypeId      : google.maps.MapTypeId.ROADMAP,
            panControl     : false,
            mapTypeControl : true,
            zoomControl    : true,
            rich_marker    : true,
            zoomControlOptions : {
                style    : google.maps.ZoomControlStyle.SMALL,
                // position : google.maps.ControlPosition.TOP_LEFT
            },
            streetViewControl : true,
            zoom              : map_options.zoom,
            // draggable         : map_options.draggable,
            scrollwheel       : map_options.scrollwheel,
            styles            : map_options.theme
        },
        element     = document.getElementById(map_options.map_id),
        marker      = null,
        infowindow  = new google.maps.InfoWindow({
            content : "..."
        }),
        markers         = [],
        map             = new google.maps.Map(element, options),
        bounds          = new google.maps.LatLngBounds(),
        markerclusterer = map_options.clusters ? new MarkerClusterer(map, []) : null,
        geocoder        = new google.maps.Geocoder(),
        map_center      = null,
		
		infoWindowBox = [],
		infoWindowContent,
		infoWindowOptions,
		infoWindowContentSwape,
		i;		

    // set map center based on main address using client side geocoding
    geocoder.geocode({ 'address': map_options.address }, function(results, status) {
        if (status == google.maps.GeocoderStatus.OK) {
            map_center = results[0].geometry.location;
            map.setCenter(map_center);
        }
    });	
	
	/* Setting Map Markers
	   --------------------------------------------------------- */
	   
    map_options.markers.forEach(function(mk, index) {
					
		infoWindowContent = document.createElement('div');
		
		if ( mk.URL === '' ) {
			mk.URL = '#';
		}
	
		// marker content Start
		infoWindowContentSwape = '<div class="infoWindow-block-container"><a href="' + mk.URL + '" title="' + mk.title + '" class="main-link">';
	
		if (mk.image !== '') {
			infoWindowContentSwape += '<div class="image-block"><div class="image-block-container"><img src="' + mk.image + '" alt="' + mk.title + '" />' + mk.image_text + '</div></div><h4>' + mk.title + '</h4><p>' + mk.description + '</p></a></div>';
		} else {
			infoWindowContentSwape += '<h4>' + mk.title + '</h4><p>' + mk.description + '</p></a></div>';
		}
	
		infoWindowContent.innerHTML = infoWindowContentSwape;
		// marker content End		
				
		infoWindowOptions = {
			zIndex: 80,
			maxWidth: 320,
			alignBottom: true,
			closeBoxMargin: '0',
			disableAutoPan: false,
			content: infoWindowContent,
			enableEventPropagation: true,
			boxClass: 'col-md-12 infoWindow-block',
			pixelOffset: new google.maps.Size(-100, 0),
			infoBoxClearance: new google.maps.Size(1, 1),
			closeBoxURL: focus_wp_uri + "/framework/shortcodes/assets/lib/js/infobox/close.png"
		};
		
		infoWindowBox[index] = new InfoBox(infoWindowOptions);
			
        // console.log(index); 
				
        // if marker has saved lat/lng values simply set the marker up
        if(mk.lat_lng != '' && mk.lat_lng != undefined) {
            mk.lat_lng = mk.lat_lng.replace(/[()\s]/g,'');
            mk.lat_lng = mk.lat_lng.split(',');			
            // console.log(mk.lat_lng);
            marker = new google.maps.Marker({
                position : {
                    lat : parseFloat(mk.lat_lng[0]),
                    lng : parseFloat(mk.lat_lng[1])
                },
                map   : map,
                icon  : mk.icon,
                title : mk.title
            });
			
            if(map_options.clusters) markerclusterer.addMarker(marker);
            google.maps.event.addListener(marker, 'click', function () {
                if(map_options.center_on_markerclick) map.setCenter(this.getPosition());
				
				// loop through all markers and close them
				for (i = 0; i < map_options.markers.length; i += 1) {
					infoWindowBox[i].close();
				}
								
				infoWindowBox[index].open(map, this);
            });
            bounds.extend(marker.position);
			markers.push(marker);
            // Fit markers
			if(map_options.fit_to_markers) map.fitBounds(bounds);
        } else {
            // get the marker lat / lng values and then set up the marker
            geocoder.geocode({ 'address': mk.address }, function(results, status) {
                if (status == google.maps.GeocoderStatus.OK) {
                    marker = new google.maps.Marker({
                        position : results[0].geometry.location,
                        map      : map,
                        icon     : mk.icon,
                        title    : mk.title
                    });
					
                    if(map_options.clusters) markerclusterer.addMarker(marker);
                    google.maps.event.addListener(marker, 'click', function () {
                        if(map_options.center_on_markerclick) map.setCenter(this.getPosition());
												
						// loop through all markers and close them
						for (i = 0; i < map_options.markers.length; i += 1) {
							infoWindowBox[i].close();
						}						
						
						infoWindowBox[index].open(map, this);
                    });
                    bounds.extend(marker.position);
					markers.push(marker);
                    // Fit markers
					if(map_options.fit_to_markers) map.fitBounds(bounds);
                }
            });
        }
    });
	
	//console.log(map_options.markers.length);
    //console.log(infoWindowBox[1]); 

}