<?php
/**
 * Used for the theme's initialization.
 */
class Focus_WP_ThemeFiles {

	function focus_wp_init($options) {
		
		/* Remove theme support. */
		add_action('init', array(&$this, 'focus_wp_remove_support'));
		
		/* Add theme support. */
		add_action('after_setup_theme', array(&$this, 'focus_wp_supports'));
		
		/* Load theme's functions. */
		$this->focus_wp_functions();
		
		/* Load theme's plugin. */
		$this->focus_wp_plugins();
		
		/* Initialize the theme's widgets. */
		add_action('widgets_init',array(&$this, 'focus_wp_widgets'));
		
	}
	
	/**
	 * Remove theme support.
	 */
	function focus_wp_remove_support() {	    	    
	    // Remove post types from portfolio posts
	    remove_post_type_support('portfolio','post-formats');
	    remove_post_type_support('portfolio','comments');
		
	    // Remove comments from pages		
	    remove_post_type_support('page','comments');
	}
	
	/**
	 * Add theme support.
	 */
	function focus_wp_supports() {
		if (function_exists('add_theme_support')) {
			
			add_theme_support( 'post-thumbnails' );
			
			//This enables post-thumbnail support for a theme.
			add_theme_support( 'title-tag' );
			
			//This enables the naviagation menu ability. 
			add_theme_support('menus');
			
			register_nav_menus(array(
				'primary-menu' => esc_html__( 'Qodux Navigation', 'focus_wp' ), 
			));
			
			//This enables post and comment RSS feed links to head. This should be used in place of the deprecated automatic_feed_links.
			add_theme_support('automatic-feed-links');
			
			// reference to: http://codex.wordpress.org/Function_Reference/add_editor_style
			add_theme_support('editor-style');
			add_theme_support( 'woocommerce' );

		}
	}
		
	/**
	 * Loads the core theme functions.
	 */
	function focus_wp_functions() {
		require_once (get_template_directory() . '/framework/functions/theme-functions.php');
		
		require_once (get_template_directory() . '/framework/includes/theme-features.php');
		require_once (get_template_directory() . '/framework/includes/sidebar.php');
		if(focus_wp_get_option('general', 'woocommerce')){
			require_once (get_template_directory() . '/framework/functions/woocommerce.php');
			require_once (get_template_directory() . '/framework/functions/woocommerce_config.php');
		}
	}

	/**
	 * Load plugins integrated in a theme.
	 */
	function focus_wp_plugins() {
		require_once (get_template_directory() . '/framework/plugins/breadcrumbs-plus/breadcrumbs-plus.php');
		require_once (get_template_directory() . '/framework/plugins/class-tgm-plugin-activation.php');
	}
	
	/**
	 * Register theme's extra widgets.
	 */
	function focus_wp_widgets() {
		/* Load each widget file. */
		require_once (get_template_directory() . '/framework/widgets/subnav.php');
		require_once (get_template_directory() . '/framework/widgets/recent.php');
		require_once (get_template_directory() . '/framework/widgets/popular.php');
		require_once (get_template_directory() . '/framework/widgets/related.php');
		require_once (get_template_directory() . '/framework/widgets/most-read.php');
		require_once (get_template_directory() . '/framework/widgets/recent-portfolio.php');
		require_once (get_template_directory() . '/framework/widgets/popular-portfolio.php');
		require_once (get_template_directory() . '/framework/widgets/contactinfo.php');
		
		/* Register each widget. */
		register_widget('Focus_WP_Widget_SubNav');
		register_widget('Focus_WP_Widget_Recent_Posts');
		register_widget('Focus_WP_Widget_Popular_Posts');
		register_widget('Focus_WP_Widget_Related_Posts');
		register_widget('Focus_WP_Widget_Most_Read_Posts');
		register_widget('Focus_WP_Widget_Recent_Portfolio_Posts');
		register_widget('Focus_WP_Widget_Popular_Portfolio_Posts');
		register_widget('Focus_WP_Widget_Contact_Info');
	}
}
?>